@@ -3,7 +3,7 @@ package Unix::Uptime::BSD;
 use warnings;
 use strict;
 
-our $VERSION='0.31_01';
+our $VERSION='0.33_01';
 $VERSION = eval $VERSION;
 
 use DateTime::Format::Strptime;
@@ -11,6 +11,7 @@ use DateTime::Format::Strptime;
 sub uptime {
     my $class = shift;
 
+    $ENV{PATH} .= ':/usr/local/sbin:/usr/sbin:/sbin';
     my $boottime = `sysctl kern.boottime`;
 
     $boottime =~ s/^\s*kern\.boottime\s*=\s*//;
@@ -31,6 +32,8 @@ sub uptime {
 no warnings qw(once);
 *uptime_hires = \&uptime;
 
+use base 'Unix::Uptime::BSD::Load';
+
 1;
 
 __END__
