@@ -3,12 +3,13 @@ package Unix::Uptime::FreeBSD;
 use warnings;
 use strict;
 
-our $VERSION='0.31_01';
+our $VERSION='0.33_01';
 $VERSION = eval $VERSION;
 
 sub uptime {
     my $class = shift;
     
+    $ENV{PATH} .= ':/usr/local/sbin:/usr/sbin:/sbin';
     my $boottime = `sysctl kern.boottime`;
     my ($boot_seconds,$boot_useconds) = $boottime =~ /\s+sec\s+=\s+(\d+),\s+usec\s+=\s+(\d+)/;
     return time() - $boot_seconds;
@@ -21,7 +22,7 @@ sub uptime_hires {
         die "uptime_hires: you need to import Unix::Uptime with ':hires'";
     }
 
-    my $boottime = `sysctl kern.boottime`;
+    my $boottime = `/sbin/sysctl kern.boottime`;
     my ($boot_seconds,$boot_useconds) = $boottime =~ /\s+sec\s+=\s+(\d+),\s+usec\s+=\s+(\d+)/;
     my $time = Time::HiRes::gettimeofday();
     my $boot_time = $boot_seconds + ($boot_useconds * (10.0**-6));
@@ -34,6 +35,8 @@ sub load_hires {
     require Time::HiRes;
 }
 
+use base 'Unix::Uptime::BSD::Load';
+
 1;
 
 __END__
